==> blobAndConquer-0.8-2.tar.gz: blobAndConquer-0.8/src/title.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void loadWidgets(char *filename);
extern bool loadGame();
extern void doGameObjects();
extern void loadTextures();
extern void loadRawModels();
extern void loadAllDefResources();
extern void renderBSP();
extern void drawWidgets();
extern void loadGameLocaleData(char *filename, bool append);
extern void doConfigOptions();
extern void newGame();
extern bool changeLanguage();

extern Audio *audio;
extern BoundingBoxManager *bbManager;
extern BSP *bsp;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern Mission *mission;
extern ModelManager *modelManager;
extern Mouse *mouse;
extern Unit *player;
extern TextureManager *textureManager;
extern UIManager *uiManager;

==> blobAndConquer-0.93-2.tar.gz: blobAndConquer-0.93/src/title.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void loadWidgets(const char *filename);
extern bool loadGame();
extern void doGameObjects();
extern void loadTextures();
extern void loadRawModels();
extern void loadAllDefResources();
extern void renderBSP();
extern void drawWidgets();
extern void doConfigOptions();
extern void newGame();
extern bool changeLanguage();
extern void renderScaledTexture(Texture *texture);

extern Audio *audio;
extern BoundingBoxManager *bbManager;
extern BSP *bsp;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern Map *map;
extern Mission *mission;
extern ModelManager *modelManager;
extern Mouse *mouse;
extern Unit *player;
extern TextureManager *textureManager;
extern UIManager *uiManager;
